@@ -6,9 +6,7 @@ etree = html.etree
 from Fishconsole import logs
 from Fishconsole import window
 from Fishconsole import fcv
-from Fishconsole import tool
-
-
+from Fishconsole import Fishsys
 
 sys = fcv.f_debug()
 sys = sys["updata"]
@@ -16,21 +14,18 @@ UPI = fcv.f_debug()
 UPI = UPI["UPI"]
 
 
-
 # 判断设备是否接入网络
 def isConnected():
     import requests
     try:
         html = requests.get("https://pypi.org/project/Fishconsole/", timeout=2)
     except:
-        logs.系统日志("》强制更新系统》官网连接失败",UPI)
+        logs.系统日志("》强制更新系统》官网连接失败", UPI)
         return False
-    logs.系统日志("》强制更新系统》官网连接成功",UPI)
+    logs.系统日志("》强制更新系统》官网连接成功", UPI)
     return True
 
 
-
-
 def 帮助():
     sys = fcv.f_debug()
     sys = sys["updata"]
@@ -55,92 +50,59 @@ def 帮助():
             if sys:
 
                 # 尝试获取缓存中的值
-                config = tool.缓存(2)
+                config = Fishsys.缓存(2)
                 fupdata = config.get("updata")
                 if fupdata:
                     # 这是Ture时执行的操作
-                    1+1
+                    1 + 1
                 else:
                     # 这是为false是执行的操作
                     config["updata"] = True
-                    tool.缓存(1, config)
-                tool.缓存(1, config)
+                    Fishsys.缓存(1, config)
+                Fishsys.缓存(1, config)
                 logs.系统日志(f"Fishconsole》help》强制更新启动")
                 exit()
             else:
-                logs.日志(f"Fishconsole》f_debug》已取消强制更新","绿色")
-
-
-
+                logs.日志(f"Fishconsole》f_debug》已取消强制更新", "绿色")
                 # 尝试获取缓存中的值
-                config = tool.缓存(2)
+                config = Fishsys.缓存(2)
                 fupdata = config.get("updata")
                 if fupdata:
                     config["updata"] = False
-                    tool.缓存(1, config)
+                    Fishsys.缓存(1, config)
         else:
             print(logs.日志(f"Fishconsole{fcv.version()} 检查更新结束,您的模块为最新版本", "绿色"))
             print(logs.日志(f"Fishconsole{fcv.version()} 已解锁，您可以使用了", "绿色"))
 
             # 尝试获取缓存中的值
-            config = tool.缓存(2)
+            config = Fishsys.缓存(2)
             fupdata = config.get("updata")
             if fupdata:
                 # 这是Ture时执行的操作
-                config["updata"]=False
-                tool.缓存(1, config)
+                config["updata"] = False
+                Fishsys.缓存(1, config)
             else:
                 # 这是为false是执行的操作
-                config["updata"]=False
-                tool.缓存(1, config)
+                config["updata"] = False
+                Fishsys.缓存(1, config)
     else:
         print(logs.日志(f"Fishconsole{fcv.version()} 检查更新结束"))
         print(logs.日志("你的设备无法访问互联网，请检查网络连接"))
 
     help_mod = logs.输入("如果您使用termux安装的话，请按1，否则按2")
     if help_mod == "1":
-        print(
-            f"logs.分割线('这是logs模块的', 'Fishconsole{fcv.version()}帮助文档'\n)"
-            "你是不是不知道怎么用的？那就让我来告诉你吧!!\n"
-            "这个函数是一个输出工具的集合，是由鱼鱼有几斤整理的\n"
-            "我整理了这几个项目\n"
-            f"{logs.颜色('这是logs模块当中的', 色选='火粉')}\n"
-            "---------------------\n"
-            "1：‘分割线’，它的作用就是弄出一个分割线，将无关的输出和自己想看到的分割线分割开来，这样就可以在一定层度上降低对头发的消耗啦\n"
-            "2：‘日志’，它的作用就是在前面加一个时间戳，主要是好看和装逼用的，但是用的好的话还是很可以的\n"
-            "3：‘颜色’，更改输出的颜色，目前支持的有：\n"
-            f"{logs.颜色('紫色', 色选='紫色')}，{logs.颜色('红色', 色选='红色')}，{logs.颜色('黄色', 色选='黄色')}，{logs.颜色('蓝色', 色选='蓝色')}，{logs.颜色('绿色', 色选='绿色')}，{logs.颜色('青色', 色选='青色')}\n"
-            f' {logs.颜色("青背", 色选="青背")}{logs.颜色("紫背", 色选="紫背")}{logs.颜色("绿背", 色选="绿背")}{logs.颜色("蓝背", 色选="蓝背")}{logs.颜色("黄背", 色选="黄背")}{logs.颜色("红背", 色选="红背")}\n'
-            " (注意哦,分割线和日志都是可以和颜色叠加使用的)\n"
-            "‘input输入加强’，原版的input支持输出提示文字，但是默认为空且不好识别，我就针对这种情况对它进行重写了一次，这一次，辨识度绝对高/dogedoge/手臂\n"
-            "---------------------\n"
-            "‘分割线’的语法是:\n"
-            "logs.分割线(标题,文本,颜色选择)\n\n"
-            "‘日志’的语法是:\n"
-            "logs.日志(显示文字,颜色选择)\n\n"
-            "‘颜色’的语法是:\n"
-            "logs.颜色(输出显示文字,颜色选择)\n\n"
-            "‘input输入加强’的语法是:\n"
-            "logs.输入(输出显示文字,颜色选择)\n\n"
-            "ps.推荐一个写法（全局参数），语法是"
-            "全局参数='红色'\n"
-            "a = 输入('a', 全局参数)\n"
-            "a = 输入('a', 全局参数)\n"
-            "a = 输入('a', 全局参数)\n"
-            "全局参数='蓝色'\n"
-            "a = 输入('a', 全局参数)\n"
-            "a = 输入('a', 全局参数)\n"
-            "a = 输入('a', 全局参数)\n"
-            "这种写法极快的提升了编写的效率，也达到了Fishconsole logs模块的初衷（我们拒绝让一个庞大的工程变得难以调试）\n"
-
-            "---------------------"
-        )
+        print(logs.日志("termux支持已被取消", "红色"))
         exit()
     else:
         res = window.列表选择对话框(
-            "关于控制台输出模块的帮助文档会显示在命令行中，选中你想查看的内容，我们将会提供相应的窗口。\n\n为什么有的地方找不到? \n因为我没做哈欠。\n\n那些1，2的模式可以用int指定int类型的嘛？\n可以，我做了类型转换，你随便造",
+            "关于控制台输出模块的帮助文档会显示在命令行中，选中你想查看的内容，我们将会提供相应的窗口。\n\n"
+            "为什么有的地方找不到? \n"
+            "因为我没做哈欠。\n\n"
+            "那些1，2的模式可以用int类型的嘛？\n"
+            "可以，我做了类型转换，你随便造\n\n"
+            "啊，pypi是真的不错，我本地写废了还可以去云端把历史版本下回来/比心/比心",
             f"Fishconsole {fcv.version()} 帮助文档",
-            ["Matplotlib中文辅助模块", "easygui中文辅助模块", "logs控制台输出辅助模块", "tool玩具模块"])
+            ["Matplotlib中文辅助模块", "easygui中文辅助模块", "logs控制台输出辅助模块", "Fishsys模块"])
         logs.系统日志(f"用户请求启动{res}")
         if res == None:
             print(logs.日志("用户取消了操作", "红色"))
@@ -148,7 +110,7 @@ def 帮助():
         if res is not None:
             for a in res:
                 if a == "logs控制台输出辅助模块":
-                    print(logs.分割线("这是logs模块的", f"Fishconsole{fcv.version()} 帮助文档", "红色"))
+                    logs.分割线("这是logs模块的", f"Fishconsole{fcv.version()} 帮助文档", "红色")
                     print(
                         "你是不是不知道怎么用的？那就让我来告诉你吧!!\n"
                         "这个函数是一个输出工具的集合，是由鱼鱼有几斤整理的\n"
@@ -162,7 +124,8 @@ def 帮助():
                         f' {logs.颜色("青背", 色选="青背")}{logs.颜色("紫背", 色选="紫背")}{logs.颜色("绿背", 色选="绿背")}{logs.颜色("蓝背", 色选="蓝背")}{logs.颜色("黄背", 色选="黄背")}{logs.颜色("红背", 色选="红背")}\n'
                         " (注意哦,分割线和日志都是可以和颜色叠加使用的)\n\n"
                         "4:‘input输入加强’，原版的input支持输出提示文字，但是默认为空且不好识别，我就针对这种情况对它进行重写了一次，这一次，辨识度绝对高/dogedoge/手臂\n"
-                        "---------------------\n"
+                        "5: ‘变量查看’，查看变量的名字，内容，类型 "
+                        "\n---------------------\n"
                         "‘分割线’的语法是:\n"
                         "logs.分割线(标题,文本,颜色选择)\n"
                         "‘日志’的语法是:\n"
@@ -170,7 +133,9 @@ def 帮助():
                         "‘颜色’的语法是:\n"
                         "logs.颜色(输出显示文字,颜色选择)\n"
                         "‘input输入加强’的语法是：\n"
-                        "logs.输入(输出显示文字,颜色选择)\n\n"
+                        "logs.输入(输出显示文字,颜色选择)\n"
+                        "‘变量查看’’的语法是：\n"
+                        "logs.变量查看（变量名: str, 变量, 色选: str = '红色'）\n\n"
                         "ps.推荐一个写法（全局参数），语法是\n"
                         "全局参数='红色'\n"
                         "a = 输入('a', 全局参数)\n"
@@ -383,8 +348,8 @@ def 帮助():
                             "然后。。。然后就没了，哈欠。。。"
                             , "matplotlib中文辅助模块 - 高级教程", "ok")
 
-                if a == "tool玩具模块":
-                    res = window.列表选择对话框("这相当于是我的一个代码仓库吧，我以后写的所有可以拿来用的小程序全都会放在这里（是不是很过分☕😉）", "tool玩具模块", [
+                if a == "Fishsys模块":
+                    res = window.列表选择对话框("这是Fishconsole的功能模块（之前是tool，但是后来功能增强了）", "Fishsys模块", [
                         "密码模块",
                         "网易云音乐模块",
                         "排名模块",
@@ -404,37 +369,37 @@ def 帮助():
                                 "嗯，就这样把\n"
                                 "------------------------\n"
                                 "加密示例：\n"
-                                "tool.密码(1，原文，密码（默认为字符串类型的空）)\n\n"
+                                "Fishsys.密码(1，原文，密码（默认为字符串类型的空）)\n\n"
                                 "解密示例：\n"
-                                "tool.密码(2，原文，密码（默认为字符串类型的空）)\n\n"
+                                "Fishsys.密码(2，原文，密码（默认为字符串类型的空）)\n\n"
                                 , "password加密模块", "ok")
                         if a == "网易云音乐模块":
                             window.弹窗(
                                 "这个模块其实就是一个爬虫，爬的网易云的歌单里面的歌，最多只能爬一首歌单的前10首，vip的只能爬前几秒，下就下在根目录（我在搞事情哈哈）\n"
                                 "-----------------------------\n\n"
                                 "示例语法\n"
-                                "tool.网易云音乐(['歌单链接1'，'歌单链接2'])"
+                                "Fishsys.网易云音乐(['歌单链接1'，'歌单链接2'])"
                                 , "网易云音乐模块", "ok")
                         if a == "排名模块":
                             window.弹窗(
                                 "这个东西呢，就是对你输入的数据排个序，然后再按照你指定的那个序号来返回\n"
                                 "-----------------------------\n\n"
                                 "语法就是\n"
-                                "tool.排名(数据源,第几个)"
+                                "Fishsys.排名(数据源,第几个)"
                                 , "排名模块", "ok")
                         if a == "文件存在性检测模块":
                             window.弹窗(
                                 "就是找文件，他返回的是布尔值，有呢就是False，没有就是Ture，虽然没什么鸟用，但是总有人要用/dogedoge/咖啡\n"
                                 "-----------------------------\n\n"
                                 "语法就是\n"
-                                "tool.文件存在性检测(文件名)"
+                                "Fishsys.文件存在性检测(文件名)"
                                 , "文件存在性检测模块", "ok")
                         if a == "缓存模块":
                             window.弹窗(
                                 "一个工程如果大起来了的话，为了可以更好的运行，就免不了使用配置文件，但是，按照普通的读取方式就是读写一个文件的话，一堆文件就会把我们搞的惊慌失措，所以我整了个这个玩意儿，它相当于是暂时帮我们解决了这个问题，现在是用列表存的，以后可能会改成字典，这要取决于我自己的体验，如果体验实在难以接受，我tm。。。"
                                 "\n-----------------------------\n\n"
                                 "语法就是\n\n"
-                                "tool.缓存(模式, '字典（请注意，字符串用单引号括起来，千万不要用双引号，否则将过不了加密',缓存文件的名字)\n\n"
+                                "Fishsys.缓存(模式, '字典（请注意，字符串用单引号括起来，千万不要用双引号，否则将过不了加密',缓存文件的名字)\n\n"
                                 "模式有两种\n\n1:写\n覆写模式就是创建缓存文件，你需要两个模式和缓存一起使用\n\n2：读\n你只需要两个参数（模式，文件名），他会返回给你一个列表\n但如果你在之前没有创建文件，那么我们将会返回一个布尔值（False）\n\n"
                                 "当然，不可能我们在任何时候都会把所有的缓存文件放在一起，所以我允许指定文件的名字\n"
                                 "但是每次都在后面指定文件的名字的话就有点废手了，为了避免这种情况，我们可以在开头就指定好文件的名字，这样就可以了\n\n"
@@ -447,6 +412,6 @@ def 帮助():
                                 "这个东西，就是先转unicode，然后再用字符串返回给你\n\n他也可以转回byte然后返回byte的内容，其实也就是密码2.0的一个辅助模块罢了，但是呢，由于一些十分令人笑哭的原因，我把它独立了出来\n"
                                 "-----------------------------\n\n"
                                 "语法就是\n"
-                                "tool.文本转Unicode(模式，原文)\n"
+                                "Fishsys.文本转Unicode(模式，原文)\n"
                                 "模式有两种，模式1：为文本转unicode\n模式2：为str类型的unicode转文字\n"
                                 , "文本转unicode", "ok")
