@@ -49,12 +49,12 @@ def 日志(text, 色选="Nona"):
         return str(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())) + str(f":{text}")
 
 
-
 # 先导入参数，一个是updata的参数FI
 
 FI = fcv.f_debug()
 FI = FI["Fl"]
 
+
 # 新建这个函数，默认情况下所有的项目都不会运行，通过传递的参数开启相应的功能（其实都一样）
 def 系统日志(text, 参数=False):
     if FI:
@@ -64,15 +64,13 @@ def 系统日志(text, 参数=False):
         if 参数:
             # 这是True时执行的，默认情况下不会执行，但是这里会有一个地方需要注意一下，因为
             # 参数被改了，所以当参数没有被再次更改为False之前其中的任何跟系统日志有关的内容就不会被输出
-            1+1
+            1 + 1
         else:
             a = 颜色(f"Fishconsole{fcv.version()}" + "》" + str(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())),
                    色选="紫色") + str(f":{text}")
             print(a)
 
 
-
-
 def 分割线(标题, text, 色选="Nona"):
     if 色选 != "Nona":
         import time
@@ -89,6 +87,11 @@ def 错误跟踪(路径: list, 内容: str, 参数):
     raise NotImplementedError(res)
 
 
+def 变量查看(变量名: str, 变量, 色选: str = "红色"):
+    print("="*63)
+    print(日志(f"  ||（{颜色('变量名', 色选)}：{变量名}）（{颜色('数据', 色选)}：{变量}）（{颜色('类型', 色选)}: {type(变量)}）||"))
+    print("="*63+"\n\n")
+
 
 # print(日志(123, 色选="红色"))
 # print(分割线("123","456","红色"))
