@@ -1,7 +1,7 @@
 # ecoding=utf-8
 import easygui
 # 虽然没什么用，但是里面的强制更新系统可以很好的牵制调用
-from Fishconsole import tool
+from Fishconsole import Fishsys
 from Fishconsole import logs
 logs.系统日志("用户调用了window模块")
 
